illustris package
=================

Submodules
----------

illustris.cartesian module
--------------------------

.. automodule:: illustris.cartesian
   :members:
   :show-inheritance:
   :undoc-members:

illustris.groupcat module
-------------------------

.. automodule:: illustris.groupcat
   :members:
   :show-inheritance:
   :undoc-members:

illustris.lhalotree module
--------------------------

.. automodule:: illustris.lhalotree
   :members:
   :show-inheritance:
   :undoc-members:

illustris.snapshot module
-------------------------

.. automodule:: illustris.snapshot
   :members:
   :show-inheritance:
   :undoc-members:

illustris.sublink module
------------------------

.. automodule:: illustris.sublink
   :members:
   :show-inheritance:
   :undoc-members:

illustris.util module
---------------------

.. automodule:: illustris.util
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: illustris
   :members:
   :show-inheritance:
   :undoc-members:
